# lib_python_jd
Módulo para exemplificar construção de projetos Python no curso

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link para o curso [PythonPro](https://pythonpro.com.br/)

[![Build Status](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd.svg?branch=main)](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd)
[![Build Status](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd.svg?branch=main)](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd)
[![Build Status](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd.svg?branch=main)](https://app.travis-ci.com/JuniorD-Isael/lib_python_jd)

Suportada versão 3 de Python

Para instalar:
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código
```console
flake8
```
